@@ -6,7 +6,7 @@ from markdownup.config import Config
 
 class Entry:
 
-    def __init__(self, context, path: Path = None, depth: int = 0):
+    def __init__(self, context, path: Path = None):
 
         path = path or context.root_path
 
@@ -15,7 +15,6 @@ class Entry:
         self.context = context
         self.config: Config = context.config
         self.path: Path = path
-        self.depth = depth
         self.uid = uuid4()
         self.name = path.name
         self.request_path = None
