@@ -10,7 +10,6 @@ from markdown.inlinepatterns import Pattern
 from markdownup.auth.auth_provider import AuthProvider
 from markdownup.cache.cache import Cache
 from markdownup.config import Config
-from markdownup.filesystem.asset_file import AssetFile
 from markdownup.filesystem.directory import Directory
 from markdownup.response import Response, ResponseException
 from markdownup.search.search_provider import get_search_response
@@ -25,7 +24,7 @@ class MarkdownUp:
         self.exclusions: List[Pattern] = list(map(lambda e: re.compile(e), config.get('content', 'exclusions')))
         self.root_path: Path = Path(config.get('content', 'root')).resolve()
         self.root: Directory = Directory(self)
-        self.theme: Theme = Theme(config)
+        self.theme: Theme = Theme(self)
         self.auth_provider: AuthProvider = AuthProvider.instance(self)
 
     def wsgi_app(self, environ, start_response):
@@ -82,9 +81,9 @@ class MarkdownUp:
             return e.response
 
         # serve theme file
-        theme_file = self.theme.path / rel_path
-        if theme_file.is_file():
-            return AssetFile(theme_file).get_response(environ)
+        theme_file = self.theme.get_file(rel_path)
+        if theme_file:
+            return theme_file.get_response(environ)
 
         # serve theme 404
         if '404' in self.theme.html:
@@ -93,7 +92,6 @@ class MarkdownUp:
                 template=self.theme.html['404'],
                 partials_dict=self.theme.html,
                 data={
-                    'title': '404 Not Found',
                     'root': self.root,
                     'auth': environ.get('auth', None)
                 }
